@@ -28,6 +28,8 @@ class PyblobLogger:
     def setup_debug_logger(self, logger_name):
         self.debug_logger = logging.getLogger('DEBUG - ' + logger_name)
         self.debug_logger.setLevel(self.DEBUG_LEVEL)
+
+        logging.getLogger("azure.core.pipeline.policies.http_logging_policy").setLevel(logging.WARNING)
 	 
         file_handler = logging.FileHandler(self.get_debug_logs_name())
         file_handler.setLevel(self.DEBUG_LEVEL)
@@ -46,6 +48,8 @@ class PyblobLogger:
         self.error_logger = logging.getLogger('ERROR - ' + logger_name)
         self.error_logger.setLevel(self.ERROR_LEVEL)
 
+        logging.getLogger("azure.core.pipeline.policies.http_logging_policy").setLevel(logging.WARNING)
+
         file_handler = logging.FileHandler(self.get_error_logs_name())
         file_handler.setLevel(self.ERROR_LEVEL)
 
@@ -81,7 +85,6 @@ class PyblobLogger:
             if index < 0:
                 print('Warning: {} file to logs not found'.format(logs_file_name))
             else:
-                print("open", logs_file_name[index:])
                 with open(logs_file_name[index:], "rb") as logs:
                     blob_client.upload_blob(logs, overwrite=True)
         except Exception as ex:
